============
Publications
============


-------
General
-------

- Delaporte-Mathurin, Rémi, Etienne A. Hodille, Jonathan Mougenot, Yann Charles, and Christian Grisolia. *Parametric Optimisation Based on TDS Experiments for Rapid and Efficient Identification of Hydrogen Transport Materials Properties*. Nuclear Materials and Energy, 27, (2021). https://doi.org/10.1016/j.nme.2021.100984.

- Delaporte-Mathurin, Rémi, Etienne A. Hodille, Jonathan Mougenot, Yann Charles, and Christian Grisolia. *Finite Element Analysis of Hydrogen Retention in ITER Plasma Facing Components Using FESTIM*. Nuclear Materials and Energy, 21, (2019). https://doi.org/10.1016/j.nme.2019.100709.


--------
Coupling
--------

- James Dark, Remi Delaporte-Mathurin, Yann Charles, Etienne A. Hodille, Christian Grisolia, and Jonathan Mougenot. *Influence of Hydrogen Trapping on WCLL Breeding Blanket Performances*. Nuclear Fusion, 61, (2021). https://doi.org/10.1088/1741-4326/ac28b0


--------
Analysis
--------

- Delaporte-Mathurin, Rémi, Etienne A. Hodille, Jonathan Mougenot, Yann Charles, and Christian Grisolia. *Parametric Optimisation Based on TDS Experiments for Rapid and Efficient Identification of Hydrogen Transport Materials Properties*. Nuclear Materials and Energy, 27, (2021). https://doi.org/10.1016/j.nme.2021.100984.

- Delaporte-Mathurin, Rémi, Hao Yang, Julien Denis, James Dark, Etienne A. Hodille, Gregory De Temmerman, Xavier Bonnin, et al. *Fuel Retention in WEST and ITER Divertors Based on FESTIM Monoblock Simulations*. Nuclear Fusion 61, (2021). https://doi.org/10.1088/1741-4326/ac2bbd.

- Hodille, Etienne Augustin, Rémi Delaporte-Mathurin, Julien Denis, Matic Pečovnik, Elodie Bernard, Yves Ferro, Ryuichi Sakamoto, et al. *Modelling of Hydrogen Isotopes Trapping, Diffusion and Permeation in Divertor Monoblocks under ITER-like Conditions*. Nuclear Fusion, 61, (2021). https://doi.org/10.1088/1741-4326/ac2abc.

- Delaporte-Mathurin, Rémi, Etienne Hodille, Jonathan Mougenot, Gregory De Temmerman, Yann Charles, and Christian Grisolia. *Parametric Study of Hydrogenic Inventory in the ITER Divertor Based on Machine Learning*. Scientific Reports, 10, (2020). https://doi.org/10.1038/s41598-020-74844-w.
